==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/host.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  host_list: 'Host List',
  uninstallable: 'Please add the host first',
  hostname: 'Hostname',
  ssh_user: 'Username',
  confirm_password: 'Confirm Password',
  input_method: 'Input Method',
  file: 'File',
  text: 'Text',
  key_file: 'Key File',
  key_text: 'Key Text',
  key_password: 'Key Password',
  confirm_key_password: 'Confirm Key Password',
  username: 'Username',
  auth_method: 'Authentication Method',
  password_auth: 'Password',
  key_auth: 'Key',
  ip_address: 'IP Address',
  component_count: 'Component Count',
  component_count_quantifier: 'Components',
  no_auth: 'No Authentication',
  agent_path: 'Agent Path',
  ssh_port: 'SSH Port',
  grpc_port: 'GRPC Port',
  description: 'Description',
  key_password_not_match: 'Key Passwords do not match.',
  default_agent_path: 'Agent application installed path, default to /opt',
  default_grpc_port: 'Agent application grpc port, default to 8835'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/host.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  host_list: 'Host List',
  uninstallable: 'Please add the host first',
  hostname: 'Hostname',
  ssh_user: 'Username',
  confirm_password: 'Confirm Password',
  input_method: 'Input Method',
  file: 'File',
  text: 'Text',
  key_file: 'Key File',
  key_text: 'Key Text',
  key_password: 'Key Password',
  confirm_key_password: 'Confirm Key Password',
  username: 'Username',
  auth_method: 'Auth Method',
  password_auth: 'Password',
  key_auth: 'Key',
  ip_address: 'IP Address',
  component_count: 'Component Count',
  component_count_quantifier: 'Components',
  no_auth: 'No Authentication',
  agent_path: 'Agent Path',
  ssh_port: 'SSH Port',
  grpc_port: 'GRPC Port',
  description: 'Description',
  operate_agent: 'Are you sure you want to {action} agent on {target} ?',
  agent: 'Agent',
  key_password_not_match: 'Key Passwords do not match.',
  default_agent_path: 'Agent application installed path, default to /opt',
  default_grpc_port: 'Agent application grpc port, default to 8835',
  default_ssh_port: 'Agent application ssh port, default to 22'
}
